==> huaweicloudsdkcodeartsinspector-3.1.127-py2.py3-none-any.whl: huaweicloudsdkcodeartsinspector/v3/model/batch_create_hosts_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchCreateHostsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'items': 'list[HostItemWithId]',
        'total': 'int'
    }

    attribute_map = {
        'items': 'items',
        'total': 'total'
    }

    def __init__(self, items=None, total=None):
        """BatchCreateHostsResponse

        The model defined in huaweicloud sdk

        :param items: 创建的主机列表
        :type items: list[:class:`huaweicloudsdkcodeartsinspector.v3.HostItemWithId`]
        :param total: 主机总数
        :type total: int
        """
        
        super(BatchCreateHostsResponse, self).__init__()

        self._items = None
        self._total = None
        self.discriminator = None

        if items is not None:
            self.items = items
        if total is not None:
            self.total = total

    @property
    def items(self):
        """Gets the items of this BatchCreateHostsResponse.

        创建的主机列表

        :return: The items of this BatchCreateHostsResponse.
        :rtype: list[:class:`huaweicloudsdkcodeartsinspector.v3.HostItemWithId`]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this BatchCreateHostsResponse.

        创建的主机列表

        :param items: The items of this BatchCreateHostsResponse.
        :type items: list[:class:`huaweicloudsdkcodeartsinspector.v3.HostItemWithId`]
        """
        self._items = items

    @property
    def total(self):
        """Gets the total of this BatchCreateHostsResponse.

        主机总数

        :return: The total of this BatchCreateHostsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this BatchCreateHostsResponse.

        主机总数

        :param total: The total of this BatchCreateHostsResponse.
        :type total: int
        """
        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchCreateHostsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsinspector-3.1.147-py2.py3-none-any.whl: huaweicloudsdkcodeartsinspector/v3/model/batch_create_hosts_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchCreateHostsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'items': 'list[HostItemWithId]',
        'total': 'int'
    }

    attribute_map = {
        'items': 'items',
        'total': 'total'
    }

    def __init__(self, items=None, total=None):
        r"""BatchCreateHostsResponse

        The model defined in huaweicloud sdk

        :param items: 创建的主机列表
        :type items: list[:class:`huaweicloudsdkcodeartsinspector.v3.HostItemWithId`]
        :param total: 主机总数
        :type total: int
        """
        
        super(BatchCreateHostsResponse, self).__init__()

        self._items = None
        self._total = None
        self.discriminator = None

        if items is not None:
            self.items = items
        if total is not None:
            self.total = total

    @property
    def items(self):
        r"""Gets the items of this BatchCreateHostsResponse.

        创建的主机列表

        :return: The items of this BatchCreateHostsResponse.
        :rtype: list[:class:`huaweicloudsdkcodeartsinspector.v3.HostItemWithId`]
        """
        return self._items

    @items.setter
    def items(self, items):
        r"""Sets the items of this BatchCreateHostsResponse.

        创建的主机列表

        :param items: The items of this BatchCreateHostsResponse.
        :type items: list[:class:`huaweicloudsdkcodeartsinspector.v3.HostItemWithId`]
        """
        self._items = items

    @property
    def total(self):
        r"""Gets the total of this BatchCreateHostsResponse.

        主机总数

        :return: The total of this BatchCreateHostsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this BatchCreateHostsResponse.

        主机总数

        :param total: The total of this BatchCreateHostsResponse.
        :type total: int
        """
        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchCreateHostsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
